# frozen_string_literal: true

module EE
  module RegistrationsHelper
    include ::Gitlab::Utils::StrongMemoize
    extend ::Gitlab::Utils::Override

    override :signup_username_data_attributes
    def signup_username_data_attributes
      super.merge(api_path: suggestion_path)
    end

    def shuffled_registration_objective_options
      options = registration_objective_options
      other = options.extract!(:other).to_a.flatten
      options.to_a.shuffle.append(other).map { |option| option.reverse }
    end

    def registration_verification_enabled?
      experiment(:registration_verification, user: current_user) do |e|
        e.candidate { true }
        e.publish_to_database
        e.run
      end
    end

    def registration_verification_data
      url = if params[:learn_gitlab_project_id].present?
              trial_getting_started_users_sign_up_welcome_path(params.slice(:learn_gitlab_project_id).permit!)
            elsif params[:combined].present? && current_user.setup_for_company
              new_trial_path
            elsif params[:project_id].present?
              continuous_onboarding_getting_started_users_sign_up_welcome_path(params.slice(:project_id).permit!)
            else
              root_path
            end

      { next_step_url: url }
    end

    private

    def redirect_path
      strong_memoize(:redirect_path) do
        redirect_to = session['user_return_to']
        URI.parse(redirect_to).path if redirect_to
      end
    end

    def registration_objective_options
      options = localized_jobs_to_be_done_choices.dup

      experiment(:bypass_registration, user: current_user) do |e|
        e.use do
          options.merge(
            joining_team: _('I’m joining my team who’s already on GitLab')
          )
        end
        e.try do
          options
        end
        e.run
      end
    end
  end
end
