import ActivityFilter from 'ee/security_dashboard/components/shared/filters/activity_filter.vue';
import VulnerabilityFilters from 'ee/security_dashboard/components/shared/vulnerability_report/vulnerability_filters.vue';
import ProjectFilter from 'ee/security_dashboard/components/shared/filters/project_filter.vue';
import ScannerFilter from 'ee/security_dashboard/components/shared/filters/scanner_filter.vue';
import SimpleFilter from 'ee/security_dashboard/components/shared/filters/simple_filter.vue';
import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
import { FILTERS } from 'ee/security_dashboard/components/shared/vulnerability_report/constants';

const { ACTIVITY, PROJECT, SEVERITY, STATUS, TOOL_SIMPLE, TOOL_VENDOR } = FILTERS;

describe('Vulnerability filters component', () => {
  let wrapper;

  const createWrapper = ({ filters }) => {
    wrapper = shallowMountExtended(VulnerabilityFilters, {
      propsData: { filters },
    });
  };

  afterEach(() => {
    wrapper.destroy();
  });

  it('emits filters-changed event when filter is changed', () => {
    createWrapper({ filters: [STATUS] });
    const filter = wrapper.findComponent(SimpleFilter);
    const data = { a: 1 };
    filter.vm.$emit('filter-changed', data);

    expect(wrapper.emitted('filters-changed')[0][0]).toMatchObject(data);
  });

  it.each`
    name             | filters          | expectedComponent
    ${'activity'}    | ${[ACTIVITY]}    | ${ActivityFilter}
    ${'project'}     | ${[PROJECT]}     | ${ProjectFilter}
    ${'severity'}    | ${[SEVERITY]}    | ${SimpleFilter}
    ${'status'}      | ${[STATUS]}      | ${SimpleFilter}
    ${'tool_simple'} | ${[TOOL_SIMPLE]} | ${SimpleFilter}
    ${'tool_vendor'} | ${[TOOL_VENDOR]} | ${ScannerFilter}
  `(`shows the expected component for filter '$name'`, ({ filters, expectedComponent }) => {
    createWrapper({ filters });

    expect(wrapper.findComponent(expectedComponent).exists()).toBe(true);
  });
});
